@@ -1,7 +1,7 @@
 #!/usr/bin/tclsh8.2
 #
 # This file is part of SAUCE, a very picky anti-spam receiver-SMTP.
-# SAUCE is Copyright (C) 1997-2001 Ian Jackson
+# SAUCE is Copyright (C) 1997-2003 Ian Jackson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: sauce.tcl,v 1.103 2001/03/21 23:53:14 ian Exp $
+# $Id: sauce.tcl,v 1.105 2003/06/15 15:46:40 ian Exp $
 
 # wishlist: blacklist even if spam-message aborted
 # wishlist: use adns client instead of host
@@ -295,7 +295,7 @@ proc bff_setup {} {
     } emsg]} {
 	log error "unable to set firewall state: $emsg"
     }
-    if {[llength $result]} { debug 1 "set firewall: $result" }
+    if {[llength $emsg]} { debug 1 "set firewall: $emsg" }
 }
 
 proc globalavfpool_start {} {
