@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 #
-# $Id: smtp.tcl,v 1.14 2003/06/15 15:46:40 ian Exp $
+# $Id: smtp.tcl,v 1.14.2.1 2004/01/14 22:56:33 ian Exp $
 
 
 ########## connection threads
@@ -274,7 +274,7 @@ proc intern_getsiteannoy {ra change} {
     if {$cv < -$annoy_love_max} { set cv -$annoy_love_max }
     ds_set site-annoy $ra \
 	    [string map {{ } a - m} [list $now $cv]] \
-	    [expr {$now + 3*$annoy_halflife}]
+	    [expr {3*$annoy_halflife}]
     if {$cv <= -$annoy_love_max/2 && $cv <= -($annoy_grumpy+$annoy_actout_max)} {
 	set irritamt Ecstatic
     } elseif {$cv <= 0} {
